==> lapisworks-1.5.6.6-sources.jar: com/luxof/lapisworks/client/JarTrinketRenderer.java <==
package com.luxof.lapisworks.client;

import com.luxof.lapisworks.init.ModItems;

import dev.emi.trinkets.api.SlotReference;
import dev.emi.trinkets.api.client.TrinketRenderer;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_583;
import net.minecraft.class_591;
import net.minecraft.class_742;
import net.minecraft.class_7833;
import net.minecraft.class_811;

/**
 * @author WireSegal
 * Created at 9:50 AM on 7/25/22.
 * <p>(added because LensTrinketRenderer also has it)
 */
public class JarTrinketRenderer implements TrinketRenderer {
    // if i unravelled that many arguments it'd be even worse to read bruh wtf
    @Override
    @SuppressWarnings("unchecked")
    public void render(class_1799 stack, SlotReference slotReference, class_583<? extends class_1309> contextModel,
            class_4587 matrices, class_4597 vertexConsumers, int light, class_1309 entity,
            float limbAngle, float limbDistance, float tickDelta, float animationProgress, float headYaw,
            float headPitch) {
        if (!(stack.method_31574(ModItems.AMEL_JAR) &&
                contextModel instanceof class_591 playerModel &&
                entity instanceof class_742 player)) return;
        matrices.method_22903();
        TrinketRenderer.followBodyRotations(entity, playerModel);
        // PRAYING this translates to the belt
        // this does NOT translate to the belt :sob: :pray:
        //TrinketRenderer.translateToRightLeg(matrices, playerModel, player);
        TrinketRenderer.translateToChest(matrices, playerModel, player);

        matrices.method_22904(-0.2, 0.1, 0.0);
        matrices.method_22907(class_7833.field_40718.rotationDegrees(180.0f));
        matrices.method_22905(0.35f, 0.35f, 0.35f);

        class_310 instance = class_310.method_1551();
        // this ItemRenderer shit seems EXTREMELY! useful for my 4-armed project
        instance.method_1480().method_23178(stack, class_811.field_4319, light,
            class_4608.field_21444, matrices, vertexConsumers, instance.field_1687, 0);
        matrices.method_22909();
    }
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/client/JarTrinketRenderer.java <==
package com.luxof.lapisworks.client;

import com.luxof.lapisworks.init.ModItems;

import dev.emi.trinkets.api.SlotReference;
import dev.emi.trinkets.api.client.TrinketRenderer;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_583;
import net.minecraft.class_591;
import net.minecraft.class_742;
import net.minecraft.class_7833;
import net.minecraft.class_811;

/**
 * @author WireSegal
 * Created at 9:50 AM on 7/25/22.
 * <p>(added because LensTrinketRenderer also has it even though the code is different)
 */
public class JarTrinketRenderer implements TrinketRenderer {
    // if i unravelled this many arguments it'd be even worse to read bruh wtf
    @Override
    @SuppressWarnings("unchecked")
    public void render(class_1799 stack, SlotReference slotReference, class_583<? extends class_1309> contextModel,
            class_4587 matrices, class_4597 vertexConsumers, int light, class_1309 entity,
            float limbAngle, float limbDistance, float tickDelta, float animationProgress, float headYaw,
            float headPitch) {
        if (!(stack.method_31574(ModItems.AMEL_JAR) &&
                contextModel instanceof class_591 playerModel &&
                entity instanceof class_742 player)) return;
        matrices.method_22903();
        TrinketRenderer.followBodyRotations(entity, playerModel);
        // PRAYING this translates to the belt
        // this does NOT translate to the belt :sob: :pray:
        //TrinketRenderer.translateToRightLeg(matrices, playerModel, player);
        TrinketRenderer.translateToChest(matrices, playerModel, player);

        matrices.method_22904(-0.2, 0.1, 0.0275);
        matrices.method_22907(class_7833.field_40718.rotationDegrees(180.0f));
        matrices.method_22905(0.35f, 0.35f, 0.35f);

        class_310 instance = class_310.method_1551();
        // this ItemRenderer shit seems EXTREMELY! useful for my 4-armed project
        instance.method_1480().method_23178(stack, class_811.field_4319, light,
            class_4608.field_21444, matrices, vertexConsumers, instance.field_1687, 0);
        matrices.method_22909();
    }
}
